time_phenotype: time_phenotype

Description Usage Arguments Details Value Examples

View source: R/time_phenotype.R

Description

Get the TIME phenotypes and TIMEscore

Usage

1

Arguments

data

The matrix of gene expression data, rows are samples and columns are genes.

Details

Use gene expression data to get the corresponding TIME phenotypes and TIMEscore

Value

a list

Examples

1
2
3
4
5
if(!require("GSVA")) BiocManager::install("GSVA",update = F,ask = F)
if(!require("clusterRepro")) install.packages("clusterRepro",update = F,ask = F)
library(TIME)
data('data')
result=time_phenotype(data2)

Zaoqu-Liu/TIME documentation built on July 18, 2020, 5:03 a.m.