Description Usage Arguments Details Value Examples
View source: R/time_phenotype.R
Get the TIME phenotypes and TIMEscore
1 |
data |
The matrix of gene expression data, rows are samples and columns are genes. |
Use gene expression data to get the corresponding TIME phenotypes and TIMEscore
a list
1 2 3 4 5 | if(!require("GSVA")) BiocManager::install("GSVA",update = F,ask = F)
if(!require("clusterRepro")) install.packages("clusterRepro",update = F,ask = F)
library(TIME)
data('data')
result=time_phenotype(data2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.